@@ -343,6 +343,14 @@ CONFIG_ENV_VARS = [
     "LAMBDA_CODE_EXTRACT_TIME",
     "THUNDRA_APIKEY",
     "THUNDRA_AGENT_JAVA_VERSION",
+    "THUNDRA_AGENT_NODE_VERSION",
+    "THUNDRA_AGENT_PYTHON_VERSION",
+    "DISABLE_CORS_CHECKS",
+    "DISABLE_CUSTOM_CORS_S3",
+    "DISABLE_CUSTOM_CORS_APIGATEWAY",
+    "EXTRA_CORS_ALLOWED_HEADERS",
+    "EXTRA_CORS_EXPOSE_HEADERS",
+    "EXTRA_CORS_ALLOWED_ORIGINS",
 ]
 
 for key, value in six.iteritems(DEFAULT_SERVICE_PORTS):
