@@ -63,6 +63,13 @@ class NoSuchImage(ContainerException):
         self.image_name = image_name
 
 
+class NoSuchNetwork(ContainerException):
+    def __init__(self, network_name: str, message=None, stdout=None, stderr=None) -> None:
+        message = message or f"Docker network {network_name} not found"
+        super().__init__(message, stdout, stderr)
+        self.network_name = network_name
+
+
 class PortMappings(object):
     """Maps source to target port ranges for Docker port mappings."""
 
@@ -247,6 +254,14 @@ class ContainerClient(metaclass=ABCMeta):
         """
         pass
 
+    @abstractmethod
+    def inspect_network(self, network_name: str) -> Dict[str, Union[Dict, str]]:
+        """Get detailed attributes of an network.
+
+        :return: Dict containing docker attributes as returned by the daemon
+        """
+        pass
+
     def get_container_name(self, container_id: str) -> str:
         """Get the name of a container by a given identifier"""
         return self.inspect_container(container_id)["Name"].lstrip("/")
@@ -577,6 +592,12 @@ class CmdDockerClient(ContainerClient):
         except NoSuchObject as e:
             raise NoSuchImage(image_name=e.object_id)
 
+    def inspect_network(self, network_name: str) -> Dict[str, Union[Dict, str]]:
+        try:
+            return self._inspect_object(network_name)
+        except NoSuchObject as e:
+            raise NoSuchNetwork(network_name=e.object_id)
+
     def get_container_ip(self, container_name_or_id: str) -> str:
         cmd = self._docker_cmd()
         cmd += [
@@ -1158,6 +1179,14 @@ class SdkDockerClient(ContainerClient):
         except APIError:
             raise ContainerException()
 
+    def inspect_network(self, network_name: str) -> Dict[str, Union[Dict, str]]:
+        try:
+            return self.client().networks.get(network_name).attrs
+        except NotFound:
+            raise NoSuchNetwork(network_name)
+        except APIError:
+            raise ContainerException()
+
     def get_container_ip(self, container_name_or_id: str) -> str:
         networks = self.inspect_container(container_name_or_id)["NetworkSettings"]["Networks"]
         network_names = list(networks)
@@ -1385,6 +1414,8 @@ class SdkDockerClient(ContainerClient):
                     except socket.timeout:
                         pass
             else:
+                if detach:
+                    return b"", b""
                 return_code = result[0]
                 if isinstance(result[1], bytes):
                     stdout = result[1]
